var { LMap, LTileLayer, LMarker } = Vue2Leaflet;

/* Wrapping CRS for 360° panorama */
/*
SimpleWrapCRS = L.extend({}, L.CRS.Simple, {
    wrapLng: [0, this.image_width],
});
*/

new Vue({
    el: '#app',
    components: { LMap, LTileLayer, LMarker },
    data: {
        markers: [],

        image_height: 0,
        image_width: 0,
        pano_id: null,
        panoTileURL: '/{z}-{x}-{y}.jpg',
        pano: null,                        /* Leaflet map */
        panoTiles: null,                   /* Tiles of the panorama */
        panoMinZoom: -8,
        panoMaxZoom: 3,
        panoZoom: 0,
        panoCenter: [0, 0],
        panoMaxBounds: null,
        panoCRS: L.CRS.Simple,

        panoOptions: {
            zoomControl: true,
        },

        panoTilesURL: '/media/tiles/243/{z}-{x}-{y}.jpg',
        panoTilesOpacity: 1.0,
        panoTilesOptions: {
            minZoom: -8,
            maxZoom: 3,
            maxNativeZoom: 0,
            noWrap: true,
            bounds: null,
        }
    },
    mounted() {
        this.image_width = 12972;
        this.image_height = 3008;
        this.panoZoom = -3;
        this.panoCenter = [-this.image_height/2, this.image_width/2];
        // Set bounds to avoid panning to infinity, but wide enough so that it's not too annoying
        // TODO: change the bounds dynamically depending on the zoom level
        this.panoMaxBounds = [[this.image_height, -0.3*this.image_width], [-2*this.image_height, 1.3*this.image_width]];
        /* Avoid loading inexistant tiles (generating lots of 404) */
        this.panoTilesOptions.bounds = [[0, 0], [-this.image_height, this.image_width]];
        
      //this.loadData();
      //this.initPano();
      //this.initMinimap();
    },
    methods: {
      initPano() {

          this.pano = L.map('pano', {
              zoomControl: true,
              crs: SimpleWrapCRS,
              center: [-this.image_height/2, this.image_width/2],
              // Set bounds to avoid panning to infinity, but wide enough so that it's not too annoying
              // TODO: change the bounds dynamically depending on the zoom level
              maxBounds: [[this.image_height, -0.3*this.image_width], [-2*this.image_height, 1.3*this.image_width]],
              //maxBounds: [[this.image_height, Number.NEGATIVE_INFINITY], [-2*this.image_height, Number.POSITIVE_INFINITY]],
              zoom: this.defaultZoomPano,
              minZoom: this.minZoomPano,
              maxZoom: this.maxZoomPano,
          });
          this.panoTiles = L.TileLayer(this.PanoTileURL, {
          //this.panoTiles = L.TileLayer('/debug/tile/{z}/{x}/{y}.jpg', {
              minZoom: this.minZoomPano,
              maxZoom: this.maxZoomPano,
              maxNativeZoom: 0,
              opacity: 1.0,
              noWrap: true,
              //noWrap: false, // For 360° panorama, but does not work as expected: https://github.com/Leaflet/Leaflet/issues/6292
              bounds: [[0, 0], [-this.image_height, this.image_width]], // Avoid loading inexistant tiles (generating lots of 404)
          });
          this.pano.addLayer(this.panoTiles);
      },
      initMinimap() {
      },
    },
});
